.Delicious_area{
    padding-bottom: 110px;
    padding-top: 150px;
    .tablist_menu{
        border-bottom: 1px solid #E5E8EA;
        margin-bottom: 60px;
        .nav{
            margin-bottom: 0px;
            li{
                margin: 0 25px;
                @media #{$mobile_device} {
                    margin: 0 4px;
                }
                a{
                    padding: 0 12px 27px 12px;
                    @include transition(.3s);
                    .single_menu{
                        .icon{
                            i{
                                font-size: 50px;
                                color: #596672;
                            }
                        }
                        h4{
                            margin-bottom: 0;
                            font-size: 16px;
                            font-weight: 400;
                            color: #596672;
                            font-family: $font1;
                        }
                    }
                    &.active {
                        position: relative;
                        .single_menu{
                            .icon{
                                i{
                                    color: #DB9A64;
                                }
                            }
                            h4{
                                color: #DB9A64;
                            }
                        }
                        &:before{
                            position: absolute;
                            left: 0;
                            width: 100%;
                            height: 2px;
                            content: '';
                            background: #DB9A64;
                            bottom: 0;
                        }
                    }
                }
            }
        }
    }
    @media #{$mobile_device} {
        padding-bottom: 50px;
    }
    .single_delicious{
        margin-bottom: 50px;
        @media #{$mobile_device} {
            display: block !important;
        }
        @media #{$tablet_device}{
            display: block !important;
        }
        .thumb{
            @include border-radius(10px);
            img{
                @include border-radius(10px);
            }
        }
        .info{
            padding-left: 28px;
            @media #{$mobile_device}{
                padding-left: 0;
                margin-bottom: 15px;
                margin-top: 20px;
            }
            @media #{$tablet_device}{
                padding-left: 0;
                margin-top: 30px;
            }
            h3{
                font-size: 24px;
                color: #001D38;
                font-weight: 400;
                font-family: $font1;
            }
            p{
                font-size: 16px;
                font-weight: 400;
                line-height: 24px;
                margin-bottom: 0;
                margin-top: 15px;
                margin-bottom: 16px;
            }
            span{
                display: block;
                font-weight: 400;
                font-size: 26px;
                color: #DB9A64;
            }
        }
    }
}